# == Class: tomcat6
#
# Full description of class tomcat6 here.
#
# === Parameters
#
# Document parameters here.
#
# [*sample_parameter*]
#   Explanation of what this parameter affects and what it defaults to.
#   e.g. "Specify one or more upstream ntp servers as an array."
#
# === Variables
#
# Here you should define a list of variables that this module would require.
#
# [*sample_variable*]
#   Explanation of how this variable affects the funtion of this class and if it
#   has a default. e.g. "The parameter enc_ntp_servers must be set by the
#   External Node Classifier as a comma separated list of hostnames." (Note,
#   global variables should not be used in preference to class parameters  as of
#   Puppet 2.6.)
#
# === Examples
#
#  class { tomcat6:
#    servers => [ 'pool.ntp.org', 'ntp.local.company.com' ]
#  }
#
# === Authors
#
# Author Name <author@domain.com>
#
# === Copyright
#
# Copyright 2014 Your name here, unless otherwise noted.
#
class tomcat6
(
	$httpPort           = 8080,
	$httpRedirectPort   = 8443,
	$httpsPort          = 8443,
	$ajpPort            = 8009,
	$ajpRedirectPort    = 8443,
	$ajpMaxThreads      = 150,
	$ajpMinSpareThreads = 25,
	$ajpMaxSpareThreads = 50
)
{
	require jdk_oracle

	include tomcat6::params

	#
	# Make sure we've got the repo we need
	#
	zypprepo { 'evergreen-11.4-for-tomcat6' :
		baseurl         => 'http://download.opensuse.org/repositories/openSUSE:/Evergreen:/11.4/standard/',
		enabled         => 1,
		autorefresh     => 0,
		name            => 'evergreen-11.4-for-tomcat6',
		gpgcheck        => 0,
	}

	$jcct5_url = 'http://suse.mobile-central.org/distribution/12.3/repo/oss/suse/noarch/jakarta-commons-collections-tomcat5-3.2-103.1.3.noarch.rpm'
	package { 'jakarta-commons-collections-tomcat5' :
		provider	=> rpm,
		ensure		=> installed,
		source		=> $jcct5_url,
	}

	package { 'tomcat6' :
		ensure	=> installed,
		require	=> [ Package[ 'jakarta-commons-collections-tomcat5' ], Zypprepo[ 'evergreen-11.4-for-tomcat6' ] ],
	}

	package { 'tomcat6-admin-webapps' :
		ensure	=> installed,
		require	=> Package[ 'tomcat6' ],
	}

	service { 'tomcat6' :
		ensure	=> running,
		enable	=> true,
		require	=> [ Package[ 'tomcat6' ], Package[ 'tomcat6-admin-webapps' ] ],
	}

	#
	# Concat instance for context.xml
	#
	concat { $params::tc_context_config:
		owner	=> 'root',
		group	=> 'root',
		mode	=> '0644',
		require	=> Package[ 'tomcat6' ],
	}
	concat::fragment { 'context_preamble' :
		target	=> $params::tc_context_config,
		order	=> 01,
		source	=> "puppet:///modules/tomcat6/etc/tomcat6/context.xml.f1",
	}
	concat::fragment { 'context_postamble' :
		target	=> $params::tc_context_config,
		order	=> 99,
		source	=> "puppet:///modules/tomcat6/etc/tomcat6/context.xml.f2",
	}

	#
	# Concat instance for server.xml
	#
        file { $params::tc_server_config :
                owner   => 'root',
                group   => 'root',
		mode	=> '0644',
                content	=> template( "tomcat6${params::tc_server_config}.erb" ),
		require	=> Package[ 'tomcat6' ],
	}

/*
	concat { $params::tc_server_config:
		owner	=> 'root',
		group	=> 'root',
		mode	=> '0644',
		require	=> Package[ 'tomcat6' ],
	}
	concat::fragment { 'preamble' :
		target	=> $params::tc_server_config,
		order	=> 01,
		source	=> "puppet:///modules/tomcat6/etc/tomcat6/server.xml.f1",
	}
	concat::fragment { 'postamble' :
		target	=> $params::tc_server_config,
		order	=> 99,
		source	=> "puppet:///modules/tomcat6/etc/tomcat6/server.xml.f2",
	}
*/

	#
	# Concat instance for tomcat-users.xml
	#
	concat { $params::tc_user_config:
		owner	=> 'root',
		group	=> 'root',
		mode	=> '0644',
		require	=> Package[ 'tomcat6' ],
	}
	concat::fragment { 'user_preamble' :
		target	=> $params::tc_user_config,
		order	=> 01,
		source	=> "puppet:///modules/tomcat6/etc/tomcat6/tomcat-users.xml.f1",
	}
	concat::fragment { 'user_postamble' :
		target	=> $params::tc_user_config,
		order	=> 99,
		source	=> "puppet:///modules/tomcat6/etc/tomcat6/tomcat-users.xml.f2",
	}

	#
	# Default: create the "admin" and "manager" roles
	#
	tomcat6::role { 'tc6_admin' :
		role	=> 'admin',
	}
	tomcat6::role { 'tc6_manager' :
		role    => 'manager',
	}
	tomcat6::role { 'tc6_gui_manager' :
		role    => 'manager-gui',
	}
	tomcat6::role { 'tc6_script_manager' :
		role    => 'manager-script',
	}

}
